@@ -17,6 +17,7 @@ from preseem.network_element_update import NetworkElement, NetworkElementUpdate,
 from fake_device import FakeDevice
 from uuid import UUID
 from preseem_protobuf.network_poller import network_poller_pb2
+from preseem.mikrotik import MikrotikApiError
 
 # TODO this should actually do something useful, and probably be in preseem-sdk
 class FakeHttpClient():
@@ -30,6 +31,21 @@ class FakeHttpClient():
     async def close(self):
         pass
 
+class FakeMikrotikClient():
+    attempted_logins = {}
+    def __init__(self, *args, **kwargs):
+        self.cfg = kwargs
+
+    async def close(self):
+        pass
+
+    async def connect(self, *args, **kwargs):
+        pass
+
+    async def login(self, *args, **kwargs):
+        self.attempted_logins[(self._user, self._pass)] = self.attempted_logins.get((self._user, self._pass), 0) + 1
+        raise MikrotikApiError('invalid credentials')
+
 
 @staticmethod
 async def fake_ping(host):
@@ -905,6 +921,38 @@ class TestNetworkElement(unittest.TestCase):
 
         self.assertEqual(ne.snmp_ne.http_credentials, [HttpCredentials('user', 'pass', [12345, 80], None), HttpCredentials('user', 'pass', [], "olt")])
 
+    def _setup_mikrotik_ne(self, role, cfg):
+        """Setup the context for a Mikrotik element with given role and config."""
+        self._await(self.reg.close())
+        self.reg = NetworkElementRegistry(self.ctx, cfg)
+        self.reg.ne_type = role
+        ne = self._await(self.reg.set('TestNE', {'name': 'Test Element', 'site': 'My Site'}))
+        # This is needed to get it past the snmp checks to do the mikrotik probe
+        ne.snmp_ne.connection_lost = False
+        ne.snmp_ne.trie['1.3.6.1.2.1.1.1.0'] = 'Test Descr'
+        ne.snmp_ne.trie['1.3.6.1.2.1.1.2.0'] = '1.3.6.1.4.1.14988.1'  # mikrotik
+        ne.snmp_ne.trie['1.3.6.1.2.1.1.3.0'] = 1234
+        ne.snmp_ne.trie['1.3.6.1.2.1.1.5.0'] = 'Test Name'
+        self.ctx.mikrotik_api_cls = FakeMikrotikClient
+        FakeMikrotikClient.attempted_logins.clear()
+        return ne
+
+    def test_mikrotik_creds(self):
+        """Test Mikrotik credentials are used for a router or AP based on role."""
+        cfg = {
+            'credentials': [
+                {'username': 'user1', 'password': 'pass1', 'role': 'ap'},
+                {'username': 'user2', 'password': 'pass2', 'role': 'router'},
+                {'username': 'user3', 'password': 'pass3'},
+            ]
+        }
+        ap_creds = {('user1', 'pass1'), ('user3', 'pass3')}
+        router_creds = {('user2', 'pass2'), ('user3', 'pass3')}
+
+        # An AP uses matching credentials.
+        ne = self._setup_mikrotik_ne('ap', cfg)
+        self._await(ne.poll())
+
     def test_send_update_1(self):
         """Verify that send_update sends network_element_update_msg when matching elem_discovery
             reference is found."""
